<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=fr_fem
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Forum de SPIP (privé et public)',
	'forum_slogan' => 'Gestion des forums privés et publics dans SPIP',
];
